@@ -1,7 +1,8 @@
-use flow_impl::{Implementation, RUN_AGAIN, RunAgain};
-use flow_impl_derive::FlowImpl;
 use serde_json::{json, Value};
 
+use flow_impl_derive::FlowImpl;
+use flowcore::{Implementation, RUN_AGAIN, RunAgain};
+
 #[derive(FlowImpl)]
 /// Multiply two matrix rows to a product
 #[derive(Debug)]
@@ -23,16 +24,17 @@ impl Implementation for MultiplyRow {
 
 #[cfg(test)]
 mod test {
-    use flow_impl::Implementation;
     use serde_json::json;
     use serde_json::Value;
 
+    use flowcore::Implementation;
+
     #[test]
     fn multiply_row() {
-        let row0 = Value::Array(vec!(json!(1), json!(2)));
-        let row1 = Value::Array(vec!(json!(3), json!(4)));
+        let row0 = Value::Array(vec![json!(1), json!(2)]);
+        let row1 = Value::Array(vec![json!(3), json!(4)]);
 
-        let inputs = vec!(row0, row1);
+        let inputs = vec![row0, row1];
 
         let multiplier = super::MultiplyRow {};
         let (result, _) = multiplier.run(&inputs);
@@ -41,4 +43,4 @@ mod test {
 
         assert_eq!(product, json!(11));
     }
-}
\ No newline at end of file
+}
