@@ -1,8 +1,9 @@
-use flow_impl::{Implementation, RUN_AGAIN, RunAgain};
-use flow_impl_derive::FlowImpl;
 use serde_json::Value;
 use serde_json::Value::Number;
 
+use flow_impl_derive::FlowImpl;
+use flowcore::{Implementation, RunAgain, RUN_AGAIN};
+
 #[derive(FlowImpl)]
 /// Calculate the square root of a number
 #[derive(Debug)]
@@ -15,7 +16,9 @@ impl Implementation for Sqrt {
 
         if let Number(ref a) = input {
             if a.is_i64() || a.is_u64() || a.is_f64() {
-                value = Some(Value::Number(serde_json::Number::from_f64(a.as_f64().unwrap().sqrt()).unwrap()));
+                value = Some(Value::Number(
+                    serde_json::Number::from_f64(a.as_f64().unwrap().sqrt()).unwrap(),
+                ));
             }
         };
 
@@ -25,9 +28,10 @@ impl Implementation for Sqrt {
 
 #[cfg(test)]
 mod test {
-    use flow_impl::Implementation;
     use serde_json::json;
 
+    use flowcore::Implementation;
+
     use super::Sqrt;
 
     #[test]
@@ -41,4 +45,4 @@ mod test {
         assert!(again);
         assert_eq!(test_9, root.unwrap());
     }
-}
\ No newline at end of file
+}
